# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/2/15 20:05

import pickle
import os


def save_obj(obj, name):
    if not os.path.exists("obj"):
        os.mkdir("obj")
    with open('obj/' + name + '.pkl', 'wb') as f:
        pickle.dump(obj, f, pickle.HIGHEST_PROTOCOL)


def load_obj(name):
    with open('obj/' + name + '.pkl', 'rb') as f:
        return pickle.load(f)



# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/2/15 20:01

from selenium import webdriver
from selenium.webdriver.common.action_chains import ActionChains
import time


def sleep(t=0.3):
    time.sleep(t)


class jselenium:

    def __init__(self, driver_path):
        self.driver = webdriver.Chrome(driver_path)

    def hover_by_xpath(self, xpath_str):
        element_to_hover_over = self.driver.find_element_by_xpath(xpath_str)
        ActionChains(self.driver).move_to_element(element_to_hover_over).perform()
        sleep()

    def hover_by_css(self, css_selector):
        element_to_hover_over = self.driver.find_element_by_css_selector(css_selector)
        ActionChains(self.driver).move_to_element(element_to_hover_over).perform()
        sleep()

    def click_by_xpath(self, xpath_str):
        self.driver.find_element_by_xpath(xpath_str).click()
        sleep()

    def main_windows_scroll(self, y, x=0):
        js = "window.scrollTo(x, y)"
        self.driver.execute_script(js)

    def windows_scroll_by_class(self, class_name, id, offset):
        """
        把省窗口，滚动条下滑到offset
        :param offset:
        :return:
        """
        js = f'document.getElementsByClassName("{class_name}")[{id}].scrollTop={offset}'
        self.driver.execute_script(js)
        sleep()



# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/2/2 10:37

"""
基础类型的扩展：list,str
"""
import random
import string
from typing import List


def list_mul(l1, l2):
    """
    列表乘法
    :param l1:
    :param l2:
    :return:
    """
    if len(l1) != len(l2):
        raise "len(l1) != len(l2)"
    products = []
    for n1, n2 in zip(l1, l2):
        products.append(n1 * n2)
    return products


def list_add(l1, l2):
    """
    列表加法
    :param l1:
    :param l2:
    :return:
    """
    products = []
    if type(l2) is not list:
        # 支持广播加法
        for n1 in l1:
            products.append(n1 + l2)
        return products

    if len(l1) != len(l2):
        raise "len(l1) != len(l2)"
    for n1, n2 in zip(l1, l2):
        products.append(n1 + n2)
    return products


def generate_random_list(bottom, top, n):
    """
    随机生成的值可以取到bottom和top
    :param bottom:
    :param top:
    :param n:
    :return:
    """
    random_list = []
    for i in range(n):
        random_list.append(random.randint(bottom, top))
    return random_list


def generate_grid(m, n, range_values=[0, 1]) -> List[List[int]]:
    """

    :param m:
    :param n:
    :param range_values: 随机生成值的范围
    :return:
    """
    assert len(range_values) == 2
    bottom = range_values[0]
    top = range_values[1]
    return [generate_random_list(bottom, top, n) for _ in range(m)]


def generate_str(n, low=True, upper=False, low_upper=False) -> str:
    """
    随机生成长度n的由26个英文字母组成的字符串
    :param n:
    :return:
    """
    if low and upper is False and low_upper is False:
        return "".join([random.choice(string.ascii_lowercase) for _ in range(n)])
    elif upper:
        return "".join([random.choice(string.ascii_uppercase) for _ in range(n)])
    else:
        return "".join([random.choice(string.ascii_lowercase + string.ascii_uppercase) for _ in range(n)])


if __name__ == '__main__':
    s = generate_str(5005)
    print(s)
